@@ -1,6 +1,7 @@
+# frozen_string_literal: true
 require "action_controller/railtie"
 
-class Browser
+module Browser
   module ActionController
     extend ActiveSupport::Concern
 
@@ -12,8 +13,8 @@ class Browser
 
     def browser
       @browser ||= Browser.new(
-        accept_language: request.headers["Accept-Language"],
-        ua: request.headers["User-Agent"]
+        request.headers["User-Agent"],
+        accept_language: request.headers["Accept-Language"]
       )
     end
   end
