@@ -1,4 +1,5 @@
-class Browser
+# frozen_string_literal: true
+module Browser
   module Meta
     class IE < Base
       def version
@@ -8,10 +9,10 @@ class Browser
       def meta
         return unless browser.ie?
 
-        meta = ""
+        meta = []
         meta << "oldie lt-ie8 lt-ie9" if version < 8
         meta << "lt-ie9" if version == 8
-        meta
+        meta.join(" ")
       end
     end
   end
