@@ -1,4 +1,5 @@
-class Browser
+# frozen_string_literal: true
+module Browser
   module Meta
     class Modern < Base
       def meta
